<!--
 * @Author: elkers
 * @Date: 2024-08-06 16:17:39
 * @LastEditors: hqs elkers@163.com
 * @LastEditTime: 2024-08-13 18:28:16
 * @FilePath: \water-qinghe-web\src\views\waterMeter\verification\index.vue
 * @Description: 水表检定
-->

 <script setup>
 import  verificationApi from "@/api/waterMeterApi/verification";
import  { nameReg ,phoneReg }  from "@/utils/regular";
 import setPostParams from "../../../utils/searchParams.js";

 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:searchParams.value.deviceId})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */
const searchParam = {
   limit:10,
   page:1
}
const pageParam = ref({
    total:0,
    limit:0,
    page:1,
})
const tableData = ref([]);
const inpTip= '请输入',selTip = '请选择';
let  tableHeader = ref({
        deviceId: '水表编号',
        verifyCompany: '检定单位',
        verifyStaff:'检定人员',
        verifyContent:'检定内容',
        verifyCost:'检定结果',
        verifyTime:'检定时间'
   })
 /** 获取列表 */
 async function getList(val) {
      loading.value = true;

 let postParam = setPostParams(val)
      await verificationApi().search(postParam).then((res) =>{
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
  /**
  *  表单相关
  */   
const  formLabel = ({
      deviceId: '水表编号',
      verifyCompany: '检定单位',
      verifyStaff:'检定人员',
      verifyContent:'检定内容',
      verifyCost:'检定结果',
      verifyTime:'检定时间'
})
 const  rules = ref({
    deviceId: [{ required: true, message: `${inpTip+formLabel.deviceId}`, trigger: "blur" }
      
    ],
    verifyCompany: [{ required: true, message: `${inpTip+formLabel.verifyCompany}`, trigger: "blur" }],
    verifyStaff: [
      { required: true, message: `${inpTip+formLabel.verifyStaff}`, trigger: "blur" },
      { pattern: nameReg, message: '请输入真实姓名!', trigger: 'blur' },
   ],
    verifyContent: [
      { required: true, message: `${inpTip+formLabel.verifyContent}`, trigger: "blur" },
      { pattern: phoneReg, message: '电话号码不正确！', trigger: 'blur' },
   ],
});
const form = ref({});
const searchParams = ref({
    keywords: '',
});
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "新增";
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   // form.value = Object.assign({},row)
   Object.keys(row).forEach(key => {  
      if (form.value.hasOwnProperty(key)) {  
         form.value[key] = row[key];  
      }  
   });
   form.value.id = row.id
   open.value = true;
   title.value = "修改";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.verifyStaff + '"的数据项?').then(function() {
    return verificationApi().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}
 

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");

//上传文件，添加图片地址信息
const uploadData = (data) => {
    form.value.headImg = data.newFileView
}
 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["supplierRef"].validate(valid => {
     if (valid) {
        form.value.verifyContent = Number(form.value.verifyContent)
       if (form.value.id != undefined) {
         verificationApi().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
         verificationApi().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
        deviceId: '',
        verifyCompany: '',
        verifyStaff:'',
        verifyContent:''
   };
   proxy.resetForm("supplierRef");
 }
 getList();
 </script>
 <template>
    <div class="app-container">
       <el-form :model="searchParams" ref="queryRef" :inline="true">
          <el-form-item label="" prop="">
             <el-input
                v-model="searchParams.deviceId"
                placeholder="请输入搜索信息"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          >
            <template #default="scope">
                <div v-if="key.toString() == 'headImg'">
                    <img :src="scope.row.headImg" class="table-headImg"/>
                </div>
            </template>
        </el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" v-has="['update',route]" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" v-has="['delete',route]" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加/修改表单 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="supplierRef" :model="form" :rules="rules" label-width='auto'>
            <el-form-item :label="formLabel.deviceId" prop="deviceId">
               <el-input v-model="form.deviceId" :placeholder="inpTip+formLabel.deviceId"/>
            </el-form-item>
            <el-form-item :label="formLabel.verifyCompany" prop="verifyCompany">
               <el-input v-model="form.verifyCompany" :placeholder="inpTip+formLabel.verifyCompany" />
            </el-form-item>
            <el-form-item :label="formLabel.verifyStaff" prop="verifyStaff">
               <el-input v-model="form.verifyStaff" :placeholder="inpTip+formLabel.verifyStaff" />
            </el-form-item>
            <el-form-item :label="formLabel.verifyContent" prop="verifyContent">
               <el-input v-model="form.verifyContent" :placeholder="inpTip+formLabel.verifyContent" />
            </el-form-item>
            <el-form-item :label="formLabel.verifyCost" prop="verifyCost">
               <el-input v-model="form.verifyCost" :placeholder="inpTip+formLabel.verifyCost" />
            </el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <style lang="scss" scoped>

</style>
 